==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/ia.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galeria",
    "There was a problem reading files from this album" : "Un problema occurreva durante le cargamento del files de iste album",
    "Aborting preview. Could not find the file" : "Annullante previsualisation. Impossibile trovar le file. ",
    "Could not move \"{file}\", target exists" : "Impossibile displaciar \"{file}\": le destination ja existe",
    "Could not move \"{file}\"" : "Impossibile displaciar  \"{file}\"",
    "No compatible server found at {remote}" : "Nulle servitor compatibile trovate a {remote}",
    "Invalid server url" : "Adresse URL de servitor non es valide",
    "Gallery view" : "Visualisation de Galeria",
    "Could not load the description" : "Impossibile cargar le description",
    "Could not load the description: " : "Impossibile cargar le description:",
    "Copyright" : "Copyright",
    "Could not load the copyright notice: " : "Impossibile cargar le notification de copyright:",
    "Copyright notice" : "Notification de copyright",
    "Link to copyright document" : "Ligamine al documento de copyright",
    "This application may not work properly on your browser." : "Iste application pote non functionar correctemente in tu navigator.",
    "For an improved experience, please install one of the following alternatives" : "Pro un melior experientia, per favor installa uno del alternativas sequente",
    "Your browser is not supported!" : "Tu navigator web non es supportate!",
    "please install one of the following alternatives" : "per favor, installa uno del alternativas sequente",
    "Album cannot be shown" : "Impossibile monstrar le album",
    "No media files found" : "Nulle files de multimedia trovate",
    "Upload pictures in the files app to display them here" : "Incarga imagines in le application Files pro visualisar los in ci ",
    "Configuration error" : "Error de configuration",
    "New" : "Nove",
    "Hide Album" : "Occultar Album",
    "Could not hide album" : "Impossibile occultar album",
    "Next" : "Sequente",
    "Play" : "Reproducer",
    "Pause" : "Pausar",
    "Previous" : "Previe",
    "Close" : "Clauder",
    "Download" : "Discargar",
    "Toggle background" : "Alternar fundo",
    "Delete" : "Deler",
    "Could not create file \"{file}\" because it already exists" : "Impossibile crear file \"{file}\" proque illo ja existe",
    "Could not create file \"{file}\"" : "Impossibile crear file \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" es un nomine de file non valide.",
    "File name cannot be empty." : "Le nomine de file non pote esser vacue.",
    "Upload" : "Incargar",
    "Error" : "Error",
    "Error while sharing" : "Error durante compartimento",
    "Error while unsharing" : "Error durante anulation del compartimento",
    "Error while changing permissions" : "Error durante modification de permissiones",
    "Shared with you and the group {group} by {owner}" : "Compartite con te e le gruppo {group} per {owner}",
    "Shared with you by {owner}" : "Compartite con te per {owner} ",
    "Share with users or groups …" : "Compartir con usatores o gruppos ...",
    "Share with users, groups or remote users …" : "Compartir con usatores, gruppos o usatores remote ...",
    "Share" : "Compartir",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Compartir con personas qui usa altere servitores per medio de lor ID de Nube Federate:\nusername@example.com/cloud",
    "Share link" : "Compartir ligamine",
    "Link" : "Ligamine",
    "Password protect" : "Proteger per contrasigno",
    "Password" : "Contrasigno",
    "Choose a password for the public link" : "Selectiona un contrasigno pro le ligamine public",
    "Allow editing" : "Permitter modificar",
    "Email link to person" : "Ligamine de e-posta a un persona",
    "Send" : "Inviar",
    "Set expiration date" : "Assignar data de expiration",
    "Expiration" : "Expiration",
    "Expiration date" : "Data de expiration",
    "An error occured. Please try again" : "Un error occurreva. Per favor, tenta de novo.",
    "Adding user..." : "Addente usator...",
    "group" : "gruppo",
    "remote" : "remote",
    "Resharing is not allowed" : "Il non es permittite compartir plus que un vice",
    "Unshare" : "Cessa de compartir",
    "notify by email" : "notificar per message de e-posta",
    "can share" : "pote compartir",
    "can edit" : "pote modificar",
    "access control" : "controlo de accesso",
    "create" : "crear",
    "change" : "modifica",
    "delete" : "deler",
    "Password protected" : "Protegite per contrasigno",
    "Sending ..." : "Inviante ...",
    "Email sent" : "Message de e-posta inviate",
    "Warning" : "Advertimento",
    "This share is password-protected" : "Iste compartimento es protegite per contrasigno",
    "The password is wrong. Try again." : "Le contrasigno es incorrecte. Tenta de novo.",
    "Sort by date" : "Ordinar per data",
    "Sort by name" : "Ordinar per nomine",
    "Cancel upload" : "Cancellar incarga",
    "Album information" : "Information del Album",
    "File list" : "Lista del files",
    "Sorry, this file could not be found." : "Pardono, il es impossibile trovar iste file.",
    "Reasons might be:" : "Le causas pote esser:",
    "the wrong file ID was provided" : "Le ID fornite pro le file esseva incorrecte",
    "the file was removed" : "le file esseva removite",
    "the file is corrupt" : "le file es corrupte",
    "the encryption key is missing" : "le clave de cryptographia es absente",
    "Here is the error message returned by the server: " : "Ci es le message de error returnate per le servitor:",
    "For more information, please contact your friendly Nextcloud administrator." : "Pro obtener plus informationes, per favor contacta tu amical administrator Nextcloud.",
    "Sorry, but the server could not fulfill your request." : "Pardono, ma le servitor non poteva exequer tu demanda.",
    "Possible reasons for the problem:" : "Possibile causas pro le problema:",
    "a conflicting app was installed" : "un application confligente esse installate",
    "a required component is missing or was disconnected" : "un componente requirite es absente o esseva disconnectite",
    "the filesystem is not readable" : "le systema de file non es legibile",
    "For more information, please contact your friendly ownCloud administrator." : "Pro obtener plus informationes, per favor contacta tu amical administrator ownCloud.",
    "Sorry, this link doesn't seem to work anymore." : "Pardono, iste ligamine sembla non functionar plus.",
    "the item was removed" : "le elemento esseva removite",
    "the link has expired" : "le ligamine ha expirate",
    "sharing is disabled" : "le compartimento de files es disactivate",
    "For more information, please ask the person who has sent you this link." : "Pro obtener plus informationes, per favor demanda le persona qui ha te inviate iste ligamine.",
    "Add to your Nextcloud" : "Adder a tu Nextcloud",
    "Picture view" : "Visualisation de Imagine"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/ia.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galeria",
    "There was a problem reading files from this album" : "Un problema occurreva durante le cargamento del files de iste album",
    "Aborting preview. Could not find the file" : "Annullante previsualisation. Impossibile trovar le file. ",
    "Could not move \"{file}\", target exists" : "Impossibile displaciar \"{file}\": le destination ja existe",
    "Could not move \"{file}\"" : "Impossibile displaciar  \"{file}\"",
    "No compatible server found at {remote}" : "Nulle servitor compatibile trovate a {remote}",
    "Invalid server url" : "Adresse URL de servitor non es valide",
    "Could not load the description" : "Impossibile cargar le description",
    "Could not load the description: " : "Impossibile cargar le description:",
    "Copyright" : "Copyright",
    "Could not load the copyright notice: " : "Impossibile cargar le notification de copyright:",
    "Copyright notice" : "Notification de copyright",
    "Link to copyright document" : "Ligamine al documento de copyright",
    "This application may not work properly on your browser." : "Iste application pote non functionar correctemente in tu navigator.",
    "For an improved experience, please install one of the following alternatives" : "Pro un melior experientia, per favor installa uno del alternativas sequente",
    "Your browser is not supported!" : "Tu navigator web non es supportate!",
    "please install one of the following alternatives" : "per favor, installa uno del alternativas sequente",
    "Album cannot be shown" : "Impossibile monstrar le album",
    "No media files found" : "Nulle files de multimedia trovate",
    "Configuration error" : "Error de configuration",
    "New" : "Nove",
    "Hide Album" : "Occultar Album",
    "Could not hide album" : "Impossibile occultar album",
    "Next" : "Sequente",
    "Play" : "Reproducer",
    "Pause" : "Pausar",
    "Previous" : "Previe",
    "Close" : "Clauder",
    "Download" : "Discargar",
    "Toggle background" : "Alternar fundo",
    "Delete" : "Deler",
    "Could not create file \"{file}\" because it already exists" : "Impossibile crear file \"{file}\" proque illo ja existe",
    "Could not create file \"{file}\"" : "Impossibile crear file \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" es un nomine de file non valide.",
    "File name cannot be empty." : "Le nomine de file non pote esser vacue.",
    "Upload" : "Incargar",
    "Error" : "Error",
    "Error while sharing" : "Error durante compartimento",
    "Error while unsharing" : "Error durante anulation del compartimento",
    "Error while changing permissions" : "Error durante modification de permissiones",
    "Shared with you and the group {group} by {owner}" : "Compartite con te e le gruppo {group} per {owner}",
    "Shared with you by {owner}" : "Compartite con te per {owner} ",
    "Share with users or groups …" : "Compartir con usatores o gruppos ...",
    "Share with users, groups or remote users …" : "Compartir con usatores, gruppos o usatores remote ...",
    "Share" : "Compartir",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Compartir con personas qui usa altere servitores per medio de lor ID de Nube Federate:\nusername@example.com/cloud",
    "Share link" : "Compartir ligamine",
    "Link" : "Ligamine",
    "Password protect" : "Proteger per contrasigno",
    "Password" : "Contrasigno",
    "Choose a password for the public link" : "Selectiona un contrasigno pro le ligamine public",
    "Allow editing" : "Permitter modificar",
    "Email link to person" : "Ligamine de e-posta a un persona",
    "Send" : "Inviar",
    "Set expiration date" : "Assignar data de expiration",
    "Expiration" : "Expiration",
    "Expiration date" : "Data de expiration",
    "An error occured. Please try again" : "Un error occurreva. Per favor, tenta de novo.",
    "Adding user..." : "Addente usator...",
    "group" : "gruppo",
    "remote" : "remote",
    "Resharing is not allowed" : "Il non es permittite compartir plus que un vice",
    "Unshare" : "Cessa de compartir",
    "notify by email" : "notificar per message de e-posta",
    "can share" : "pote compartir",
    "can edit" : "pote modificar",
    "access control" : "controlo de accesso",
    "create" : "crear",
    "change" : "modifica",
    "delete" : "deler",
    "Password protected" : "Protegite per contrasigno",
    "Sending ..." : "Inviante ...",
    "Email sent" : "Message de e-posta inviate",
    "Warning" : "Advertimento",
    "This share is password-protected" : "Iste compartimento es protegite per contrasigno",
    "The password is wrong. Try again." : "Le contrasigno es incorrecte. Tenta de novo.",
    "Sort by date" : "Ordinar per data",
    "Sort by name" : "Ordinar per nomine",
    "Cancel upload" : "Cancellar incarga",
    "Album information" : "Information del Album",
    "File list" : "Lista del files",
    "Sorry, this file could not be found." : "Pardono, il es impossibile trovar iste file.",
    "Reasons might be:" : "Le causas pote esser:",
    "the wrong file ID was provided" : "Le ID fornite pro le file esseva incorrecte",
    "the file was removed" : "le file esseva removite",
    "the file is corrupt" : "le file es corrupte",
    "the encryption key is missing" : "le clave de cryptographia es absente",
    "Here is the error message returned by the server: " : "Ci es le message de error returnate per le servitor:",
    "For more information, please contact your friendly Nextcloud administrator." : "Pro obtener plus informationes, per favor contacta tu amical administrator Nextcloud.",
    "Sorry, but the server could not fulfill your request." : "Pardono, ma le servitor non poteva exequer tu demanda.",
    "Possible reasons for the problem:" : "Possibile causas pro le problema:",
    "a conflicting app was installed" : "un application confligente esse installate",
    "a required component is missing or was disconnected" : "un componente requirite es absente o esseva disconnectite",
    "the filesystem is not readable" : "le systema de file non es legibile",
    "Sorry, this link doesn't seem to work anymore." : "Pardono, iste ligamine sembla non functionar plus.",
    "the item was removed" : "le elemento esseva removite",
    "the link has expired" : "le ligamine ha expirate",
    "sharing is disabled" : "le compartimento de files es disactivate",
    "For more information, please ask the person who has sent you this link." : "Pro obtener plus informationes, per favor demanda le persona qui ha te inviate iste ligamine.",
    "Add to your Nextcloud" : "Adder a tu Nextcloud",
    "Picture view" : "Visualisation de Imagine",
    "Gallery view" : "Visualisation de Galeria"
},
"nplurals=2; plural=(n != 1);");
